@@ -1,6 +1,6 @@
 var searchData=
 [
   ['libreoffice_0',['LibreOffice',['../index.html',1,'']]],
-  ['list_1',['list',['../a00518.html',1,'Deprecated List'],['../a00519.html',1,'Todo List']]],
+  ['list_1',['List',['../a00518.html',1,'Deprecated List'],['../a00519.html',1,'Todo List']]],
   ['logging_20functionality_2',['Basic logging functionality.',['../a02496.html',1,'']]]
 ];
