@@ -9,7 +9,7 @@ var searchData=
   ['chartdatapoint_6',['ChartDataPoint',['../namespacecom_1_1sun_1_1star_1_1chart.html#a9335f12de589754bf3632ff79ad2e520',1,'com::sun::star::chart']]],
   ['choices_7',['Choices',['../structcom_1_1sun_1_1star_1_1sdbc_1_1DriverPropertyInfo.html#acdf2a8d50cc19e1b3b0a7eb3ee206a0c',1,'com::sun::star::sdbc::DriverPropertyInfo']]],
   ['cmisproperties_8',['CmisProperties',['../interfacecom_1_1sun_1_1star_1_1document_1_1XCmisDocument.html#a5b8207c3a83025d53ccfdf8fa9356c03',1,'com::sun::star::document::XCmisDocument']]],
-  ['color_9',['color',['../namespacecom_1_1sun_1_1star_1_1rendering.html#a6e6c5d8e54f930a67b20875cb6300ef2',1,'com::sun::star::rendering::Color'],['../namespacecom_1_1sun_1_1star_1_1util.html#a1eba7fdd59cb0581d2b072a5798bd75d',1,'com::sun::star::util::Color']]],
+  ['color_9',['Color',['../namespacecom_1_1sun_1_1star_1_1rendering.html#a6e6c5d8e54f930a67b20875cb6300ef2',1,'com::sun::star::rendering::Color'],['../namespacecom_1_1sun_1_1star_1_1util.html#a1eba7fdd59cb0581d2b072a5798bd75d',1,'com::sun::star::util::Color']]],
   ['colorcomponent_10',['ColorComponent',['../namespacecom_1_1sun_1_1star_1_1rendering.html#a22cfb0d628f89a8edb356ae3231d4e22',1,'com::sun::star::rendering']]],
   ['colorscaleentries_11',['ColorScaleEntries',['../servicecom_1_1sun_1_1star_1_1sheet_1_1ColorScale.html#ab56ac80a190cd9175c8c23f1723ad6cc',1,'com::sun::star::sheet::ColorScale']]],
   ['colorstopsequence_12',['ColorStopSequence',['../namespacecom_1_1sun_1_1star_1_1awt.html#acbd949526183e624def9e759674aa4ec',1,'com::sun::star::awt']]],
@@ -17,14 +17,15 @@ var searchData=
   ['connectinfo_14',['ConnectInfo',['../servicecom_1_1sun_1_1star_1_1sdb_1_1DatabaseAccess.html#ab362be563d4bd6719ea34c9e3e585bb5',1,'com::sun::star::sdb::DatabaseAccess']]],
   ['connectioninfo_15',['ConnectionInfo',['../servicecom_1_1sun_1_1star_1_1sdb_1_1DataAccessDescriptor.html#abb4d3d1cf255fa5e1cb6b10a92880a5b',1,'com::sun::star::sdb::DataAccessDescriptor']]],
   ['constraints_16',['Constraints',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XSolver.html#a5b66c84aae10e3e2f55aaa7c80a37f13',1,'com::sun::star::sheet::XSolver']]],
-  ['coordinates_17',['Coordinates',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapePath.html#a90d49f3bdde86c9fefc099e1c7c7827c',1,'com::sun::star::drawing::EnhancedCustomShapePath']]],
-  ['coordinatesequence_18',['CoordinateSequence',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a8277e08f09b131243b715893b903e0b9',1,'com::sun::star::drawing']]],
-  ['coordinatesequencesequence_19',['CoordinateSequenceSequence',['../namespacecom_1_1sun_1_1star_1_1drawing.html#ad88515aa1b0941ff1dad60f758962772',1,'com::sun::star::drawing']]],
-  ['coordinatesystems_20',['CoordinateSystems',['../servicecom_1_1sun_1_1star_1_1chart2_1_1LogicTargetModel.html#a3b4f48bdbac5fc580fafd1f8cbbf3d66',1,'com::sun::star::chart2::LogicTargetModel']]],
-  ['coordinatesystemtypeid_21',['CoordinateSystemTypeID',['../namespacecom_1_1sun_1_1star_1_1chart2.html#a761292ad88e29c1a3091f5670cbade7c',1,'com::sun::star::chart2']]],
-  ['copiesto_22',['CopiesTo',['../servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#aa463af48a35ce0c5fc6c341463e29afc',1,'com::sun::star::text::MailMerge']]],
-  ['creationarguments_23',['CreationArguments',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XController2.html#a7e6db858a69869a7377f36ea51a2f441',1,'com::sun::star::frame::XController2']]],
-  ['criteria_24',['Criteria',['../structcom_1_1sun_1_1star_1_1ucb_1_1SearchInfo.html#ad00f2f44f640b57f6f1bcb7a1d6c20c7',1,'com::sun::star::ucb::SearchInfo']]],
-  ['customlabelfields_25',['CustomLabelFields',['../servicecom_1_1sun_1_1star_1_1chart2_1_1DataPointProperties.html#afadb18024e7634b9c0d029462840af23',1,'com::sun::star::chart2::DataPointProperties']]],
-  ['customshapegeometry_26',['customshapegeometry',['../interfacecom_1_1sun_1_1star_1_1report_1_1XShape.html#ab32992b6ac0900fdd336e55a99f87436',1,'com::sun::star::report::XShape::CustomShapeGeometry'],['../servicecom_1_1sun_1_1star_1_1drawing_1_1CustomShape.html#ab32992b6ac0900fdd336e55a99f87436',1,'com::sun::star::drawing::CustomShape::CustomShapeGeometry']]]
+  ['contributor_17',['Contributor',['../interfacecom_1_1sun_1_1star_1_1document_1_1XDocumentProperties2.html#a15750bb2ca12a035fcdee7bff4745785',1,'com::sun::star::document::XDocumentProperties2']]],
+  ['coordinates_18',['Coordinates',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapePath.html#a90d49f3bdde86c9fefc099e1c7c7827c',1,'com::sun::star::drawing::EnhancedCustomShapePath']]],
+  ['coordinatesequence_19',['CoordinateSequence',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a8277e08f09b131243b715893b903e0b9',1,'com::sun::star::drawing']]],
+  ['coordinatesequencesequence_20',['CoordinateSequenceSequence',['../namespacecom_1_1sun_1_1star_1_1drawing.html#ad88515aa1b0941ff1dad60f758962772',1,'com::sun::star::drawing']]],
+  ['coordinatesystems_21',['CoordinateSystems',['../servicecom_1_1sun_1_1star_1_1chart2_1_1LogicTargetModel.html#a3b4f48bdbac5fc580fafd1f8cbbf3d66',1,'com::sun::star::chart2::LogicTargetModel']]],
+  ['coordinatesystemtypeid_22',['CoordinateSystemTypeID',['../namespacecom_1_1sun_1_1star_1_1chart2.html#a761292ad88e29c1a3091f5670cbade7c',1,'com::sun::star::chart2']]],
+  ['copiesto_23',['CopiesTo',['../servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#aa463af48a35ce0c5fc6c341463e29afc',1,'com::sun::star::text::MailMerge']]],
+  ['creationarguments_24',['CreationArguments',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XController2.html#a7e6db858a69869a7377f36ea51a2f441',1,'com::sun::star::frame::XController2']]],
+  ['criteria_25',['Criteria',['../structcom_1_1sun_1_1star_1_1ucb_1_1SearchInfo.html#ad00f2f44f640b57f6f1bcb7a1d6c20c7',1,'com::sun::star::ucb::SearchInfo']]],
+  ['customlabelfields_26',['CustomLabelFields',['../servicecom_1_1sun_1_1star_1_1chart2_1_1DataPointProperties.html#afadb18024e7634b9c0d029462840af23',1,'com::sun::star::chart2::DataPointProperties']]],
+  ['customshapegeometry_27',['CustomShapeGeometry',['../servicecom_1_1sun_1_1star_1_1drawing_1_1CustomShape.html#ab32992b6ac0900fdd336e55a99f87436',1,'com::sun::star::drawing::CustomShape::CustomShapeGeometry'],['../interfacecom_1_1sun_1_1star_1_1report_1_1XShape.html#ab32992b6ac0900fdd336e55a99f87436',1,'com::sun::star::report::XShape::CustomShapeGeometry']]]
 ];
